<?php
/**
 * @file
 * totem_user.theme.inc
 */

/**
 * Implements MODULE_preprocess_page().
 */
function totem_user_preprocess_page(&$vars) {

  if ($vars['is_admin']) {
    $vars['is_user_tab'] = FALSE;
    return;
  }

  // Add module UI assets
  drupal_add_css(drupal_get_path('module', 'totem_user') . '/theme/totem_user.css');
  drupal_add_js(drupal_get_path('module', 'totem_user') . '/theme/totem_user.js', array(
    'scope' => 'footer',
  ));

  // Homepage = user profile if logged in.
  if ($vars['is_front']) {
    if (user_is_logged_in()) {
      drupal_goto('user');
    }
  }

  // If not logged in, force user to homepage account options; we don't want to
  // bother with theming all the core pages and creating a secondary UX for
  // the same functionality.
  if (!user_is_logged_in()) {
    if (in_array(drupal_get_path_alias(), array('user', 'user/login', 'user/password', 'user/register'))) {
      drupal_goto('');
    }
  }

  // Adjustments for page--user.tpl.php
  if (in_array('page__user', $vars['theme_hook_suggestions'])) {

    $local_task = arg(2);
    $vars['is_user_tab'] = !empty($local_task);
    if ($vars['is_user_tab']) {
      // Tab-page callback; use ninjutsu fighting style to rearrange renderable
      // arrays. (Note hardcoded duplication of standard Omega markup
      // in page--user.tpl.php.)
      $page = &$vars['page'];

      $vars['wrapper_css_content'] = ' ' . $page['content']['content']['content']['#data']['wrapper_css'];
      $vars['wrapper_css_sidebar_first'] = NULL;
      if (!empty($page['content']['content']['sidebar_first'])) {
        $vars['wrapper_css_sidebar_first'] = ' ' . $page['content']['content']['sidebar_first']['#data']['wrapper_css'];
      }
    }
  }

}
/**
 * Implements MODULE_preprocess_node().
 */
function totem_user_preprocess_node(&$vars) {

  $node = &$vars['node'];

  if (!empty($node->uid)) {
    // See @totem_user_user_view_alter for build of "images"
    // array and fix for use of default user picture.
    $account = user_load($node->uid);
    $account = user_view($account, 'teaser');
    $vars['user_picture'] = $account['#account']->content['images'][variable_get('user_picture_style')];
  }

}
/**
 * Implements MODULE_preprocess_username().
 */
function totem_user_preprocess_username(&$vars) {
  // Do all the default stuff
  template_preprocess_username($vars);

  // Reset name to untrimmed string
  $name = $vars['name_raw'] = format_username($vars['account']);
  $vars['name'] = check_plain($name);
}
/**
 * Implements MODULE_preprocess_user_profile().
 */
function totem_user_preprocess_user_profile(&$vars) {

  global $user;

  $account = $vars['elements']['#account'];

  // @see totem_user_user_view_alter()
  // for $account->content population.
  foreach ($account->content as $key => $meta) {
    $vars['elements'][$key] = $account->content[$key];
  }

  // Add Owner/Manager label to profile.
  $vars['title_prefix']['label_perms'] = $vars['elements']['label_perms'];

  // Helpful $user_profile variable for templates.
  foreach (element_children($vars['elements']) as $key) {

    // Set CSV for term fields.
    if (!empty($vars['elements'][$key]['#field_type'])) {
      if ($vars['elements'][$key]['#field_type'] == 'taxonomy_term_reference') {
        $items = array();
        foreach ($vars['elements'][$key]['#items'] as $meta) {
          $items[] = $meta['taxonomy_term']->name;
        }

        $vars['elements'][$key] = array(
          '#markup' => implode(', ', $items),
        );
      }
    }

    // Assign field to template's $user_profile var.
    $vars['user_profile'][$key] = $vars['elements'][$key];

    // Hide all fields by default.
    hide($vars['user_profile'][$key]);
  }

  // Preprocess fields.
  field_attach_preprocess('user', $account, $vars['elements'], $vars);

  // Set template vars.
  $vars['view_mode'] = $vars['elements']['#view_mode'];
  $vars['is_own_profile'] = ($account->uid == $user->uid);
  if ($vars['is_own_profile']) {
    $vars['classes_array'][] = 'self';
  }

  // Add class to support custom "View more" paging.
  $vars['classes_array'][] = 'pager-entity';

  if ($vars['view_mode'] == 'teaser') {
    return;
  }

  // Everything below is only applicable to full profile view.
  $vars['classes_array'][] = 'profile';

  $vars['title'] = $vars['elements']['menu_local_task']['#title'];

}
